package HTML::FormHandler::Base;
# ABSTRACT: stub
use Moose;

with 'HTML::FormHandler::Widget::Form::Simple';

1;

__END__
=pod

=head1 NAME

HTML::FormHandler::Base - stub

=head1 VERSION

version 0.36003

=head1 AUTHOR

FormHandler Contributors - see HTML::FormHandler

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Gerda Shank.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

